## START: Set by rpmautospec
## (rpmautospec version 0.2.5)
%define autorelease(e:s:pb:) %{?-p:0.}%{lua:
    release_number = 1;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{?dist}
## END: Set by rpmautospec

%global forgeurl https://github.com/fastfloat/fast_float

# Test data is stored in a separate git repository. We should always use the
# latest commit at the time of the release we are packaging.
%global stf_commit 97a0b2e638feb479387554cf253e346500541e7e
%global stf_forgeurl https://github.com/fastfloat/supplemental_test_files

# Build and run exhaustive tests?
#
# These really do take a long time—at least an hour on the fastest machines,
# and over ten hours on s390x (affected also by limited parallelism). Some
# tests cover the entire single-precision domain, about four billion inputs.
# Still, we can finish before we hit any timeouts, and running the exhaustive
# tests brings peace of mind.
%bcond_without exhaustive

Name:           fast_float
Summary:        Fast & exact implementation of C++ from_chars for float/double
Version:        3.2.0
%forgemeta
Release:        %autorelease

URL:            %{forgeurl}
# README.md:
#   Licensed under either of Apache License, Version 2.0 or MIT license at your
#   option.
License:        ASL 2.0 or MIT

Source0:        %{forgesource}
Source1:        %{stf_forgeurl}/archive/%{stf_commit}/supplemental_test_files-%{stf_commit}.tar.gz

BuildRequires:  gcc-c++
BuildRequires:  cmake
# Our choice; the default make backend should work just as well
BuildRequires:  ninja-build

BuildRequires:  doctest-devel
# Doctest is header-only, so we must BR:
BuildRequires:  doctest-static

BuildRequires:  symlinks

# No compiled binaries are installed, so this would be empty.
%global debug_package %{nil}

%global common_description %{expand:
The fast_float library provides fast header-only implementations for the C++
from_chars functions for float and double types. These functions convert ASCII
strings representing decimal values (e.g., 1.3e10) into binary types. We
provide exact rounding (including round to even). In our experience, these
fast_float functions many times faster than comparable number-parsing functions
from existing C++ standard libraries.}

%description %{common_description}


%package devel
Summary:        %{summary}

# Header-only library
Provides:       fast_float-static = %{version}-%{release}

Requires:       cmake-filesystem

%description devel %{common_description}


%prep
%forgeautosetup
%setup -q -T -D -b 1
# Compiling with -Werror makes sense for upstream CI, but is excessively strict
# for downstream builds across a variety of compiler versions.
sed -r -i 's/-Werror//' tests/CMakeLists.txt


%build
# Partially emulate the activity of FetchContent_Declare() in
# tests/CMakeLists.txt so that we can run the tests offline.
mkdir -p '%{_vpath_builddir}/_deps'
ln -s "${PWD}/../supplemental_test_files-%{stf_commit}/" \
    '%{_vpath_builddir}/_deps/supplemental_test_files-src'

%cmake \
    -GNinja \
    -DFETCHCONTENT_FULLY_DISCONNECTED:BOOL=ON \
    -DSYSTEM_DOCTEST:BOOL=ON \
    -DFASTFLOAT_TEST:BOOL=ON \
    -DFASTFLOAT_EXHAUSTIVE:BOOL=%{?with_exhaustive:ON}%{?!with_exhaustive:OFF}
%cmake_build


%install
%cmake_install

# We add symbolic links to the .cmake files installed in the location preferred
# by upstream, from a location that is more conventional for Linux (and is in
# the default CMake module search path).
install -d '%{buildroot}%{_libdir}/cmake/fast_float'
ln -s -v %{buildroot}%{_datadir}/FastFloat/*.cmake \
    '%{buildroot}%{_libdir}/cmake/fast_float/'
# Convert the absolute symlinks in the buildroot to relative ones.
symlinks -c -o '%{buildroot}%{_libdir}/cmake/fast_float/'


%check
%ctest


%files devel
%license LICENSE-APACHE
%license LICENSE-MIT
%doc AUTHORS
%doc CONTRIBUTORS
%doc README.md

%{_includedir}/fast_float

%{_datadir}/FastFloat
%{_libdir}/cmake/fast_float


%changelog
* Tue Sep 21 2021 Benjamin A. Beasley <code@musicinmybrain.net> 3.2.0-1
- Update to 3.2.0 (close RHBZ#2006183)

* Thu Sep 16 2021 Benjamin A. Beasley <code@musicinmybrain.net> 3.1.0-1
- Update to 3.1.0 (close RHBZ#2004552)

* Tue Sep 14 2021 Benjamin A. Beasley <code@musicinmybrain.net> 3.0.0-1
- Update to 3.0.0

* Wed Aug 04 2021 Benjamin A. Beasley <code@musicinmybrain.net> 2.0.0-1
- Fix version number

* Wed Jul 21 2021 Fedora Release Engineering <releng@fedoraproject.org> 1.1.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Sun Jul 11 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 1.1.2-3
- Drop EPEL8 support from Fedora branch

* Sat Jul 10 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 1.1.2-2
- BR: doctest-static now that it is available

* Mon Jun 21 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 1.1.2-1
- Update to 1.1.2
- Drop fast_float-1.1.1-system-doctest.patch; now merged upstream
- Add EPEL8 support
- Do not compile tests with -Werror

* Mon Jun 21 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 1.1.1-1
- Initial package

